@@ -1,5 +1,3 @@
-from __future__ import division, print_function
-
 import numpy as np
 from numpy.linalg import LinAlgError
 from scipy.optimize._numdiff import approx_derivative
@@ -218,20 +216,20 @@ class Objective(BaseObjective):
         if lnsigma is not None:
             self.lnsigma = possibly_create_parameter(lnsigma, 'lnsigma')
 
-        self.__use_weights = use_weights
+        self._use_weights = use_weights
         self.transform = transform
         self.logp_extra = logp_extra
         self.name = name
         if name is None:
             self.name = id(self)
 
-    def __repr__(self):
+    def __str__(self):
         s = ["{:_>80}".format('')]
         s.append('Objective - {0}'.format(self.name))
 
         # dataset name
         if self.data.name is None:
-            s.append('Dataset = {0}'.format(repr(self.data)))
+            s.append('Dataset = {0}'.format(self.data))
         else:
             s.append('Dataset = {0}'.format(self.data.name))
 
@@ -239,10 +237,18 @@ class Objective(BaseObjective):
         s.append('chi2 = {0}'.format(self.chisqr()))
         s.append('Weighted = {0}'.format(self.weighted))
         s.append('Transform = {0}'.format(self.transform))
-        s.append(repr(self.parameters))
+        s.append(str(self.parameters))
 
         return '\n'.join(s)
 
+    def __repr__(self):
+        return ("Objective({model!r}, {data!r},"
+                " lnsigma={lnsigma!r},"
+                " use_weights={_use_weights},"
+                " transform={transform!r},"
+                " logp_extra={logp_extra!r},"
+                " name={name!r})".format(**self.__dict__))
+
     @property
     def weighted(self):
         """
@@ -250,11 +256,11 @@ class Objective(BaseObjective):
         objective using them?
 
         """
-        return self.data.weighted and self.__use_weights
+        return self.data.weighted and self._use_weights
 
     @weighted.setter
     def weighted(self, use_weights):
-        self.__use_weights = bool(use_weights)
+        self._use_weights = bool(use_weights)
 
     @property
     def npoints(self):
@@ -448,7 +454,7 @@ class Objective(BaseObjective):
         """
         self.setp(pvals)
 
-        logp = np.sum(param.logp() for param in self.varying_parameters())
+        logp = np.sum([param.logp() for param in self.varying_parameters()])
 
         if not np.isfinite(logp):
             return -np.inf
@@ -795,14 +801,17 @@ class GlobalObjective(Objective):
             raise ValueError("All the objectives must be either weighted or"
                              " unweighted, you cannot have a mixture.")
 
-    def __repr__(self):
+    def __str__(self):
         s = ["{:_>80}".format('\n')]
         s.append('--Global Objective--')
         for obj in self.objectives:
-            s.append(repr(obj))
+            s.append(str(obj))
             s.append('\n')
         return '\n'.join(s)
 
+    def __repr__(self):
+        return "GlobalObjective({0})".format(repr(self.objectives))
+
     @property
     def weighted(self):
         """
@@ -1019,6 +1028,9 @@ class Transform(object):
             raise ValueError("The form parameter must be one of [None, 'lin',"
                              " 'logY', 'YX4', 'YX2']")
 
+    def __repr__(self):
+        return "Transform({0})".format(repr(self.form))
+
     def __call__(self, x, y, y_err=None):
         """
         Calculate the transformed data
